////////////////////////////////////////////////////////////////////////////////
//
//	Author: Leblanc Christophe < christopheleblanc@gmx.com >
//	
//	-This code is distributed for free without any warrantee.
//	-You can use it and redistribute it without restrictions.
//	
////////////////////////////////////////////////////////////////////////////////

function RandomSquareGenerator(phaser, game){
	
	var th_ = this;
	
	var graphics;
	
	var nRows = 15;
	var nCols = 30;
	
	var cellSize = 30;
	
	this.x = 0;
	this.y = 0;
	
	this.rectangles = [];
	
	var timedEvent;
	
	this.totalWidth = 0;
	this.totalHeight = 0;
	
	var pointedRowX = 0;
	var pointedRowY = 0;
	
	this.create = function(){
		
		graphics = phaser.add.graphics({x: 0, y: 0});
		
	}
	
	function onSquareOutComplete(tween, targets, arg){
		for (var j = 0; j < arg.tweens.length; j++){
			if(arg.tweens[j].progress != 1){
				arg.tweens[j].stop();
				
			}
			
		}
		phaser.tweens.killTweensOf(arg);
		
		arg.tweens = [];
	}
	
	this.point = function(pointx, pointy){
		
		pointedRowX = Math.floor( ( (pointx - th_.x) / th_.totalWidth ) * nCols) + 1;
		pointedRowY = Math.floor( ( (pointy - th_.y) / th_.totalHeight ) * nRows) + 1;
		
		for (var i = 0; i < th_.rectangles.length; i++){
			
			var rect = th_.rectangles[i];
			
			var xDec = cellPow(rect.idx[0], pointedRowX); 
			var yDec = cellPow(rect.idx[1], pointedRowY); 
			
			if(rect.idx[0] == pointedRowX && rect.idx[1] == pointedRowY){
				
				rect.scale = 1;
				
				rect.fillAlpha = 1;
				
				phaser.tweens.killTweensOf(rect);
				
				rect.active = true;
			}
			else{
				if(rect.active){
					rect.active = false;
					
					
					
					var tween = phaser.tweens.add({
						targets: rect,
						scale: 0,
						fillAlpha: 0,
						ease: 'Power1',
						duration: 1000,
						onComplete: onSquareOutComplete,
						onCompleteParams: [ rect ]
					});
					
					rect.tweens.push(tween);
					
					
				}
			}
			
		}
		
	}
	
	function onCompleteHandler(tween, targets, arg){
		
		for (var i = 0; i < th_.rectangles.length; ++i){
			
			var rect = th_.rectangles[i];
			
			if(rect == arg){
				th_.rectangles.splice(i, 1);
			}

		}
		
	}
	
	this.start = function(){
		
		
		th_.totalWidth = nCols * cellSize;
		th_.totalHeight = nRows * cellSize;
		
		th_.x = (game.canvas.width - th_.totalWidth) * 0.5;
		th_.y = (game.canvas.height - th_.totalHeight) * 0.5;
		
		for(var i = 0; i < nRows; i++){
			
			var y = i * cellSize;
			
			for(var j = 0; j < nCols; j++){
				
				var x = j * cellSize;
				
				var rec = new Square();
				rec.x = x;
				rec.y = y;
				rec.width = cellSize;
				rec.height = cellSize;
				
				rec.idx[0] = j;
				rec.idx[1] = i;
				
				
				th_.rectangles.push(rec);
				
			}
			
		}
		
		
	}
	
	function cellPow(cellA, cellB){
		var dif;
		if(cellA > cellB){
			dif = cellA - cellB;
		}
		else if(cellA < cellB){
			dif = cellB - cellA;
		}
		else{
			dif = 0;
		}
		
		if(dif == 0){
			return 1;
		}
		else if(dif == 1){
			return 0.5;
		}
		else if(dif == 2){
			return 0.25;
		}
		else{
			return 0;
		}
		
	}
	
	this.update = function(){
		
		
		
		graphics.clear();
    
		for (var i = 0; i < th_.rectangles.length; ++i){
			
			var rect = th_.rectangles[i];
			graphics.fillStyle(0x000000, rect.fillAlpha);
			graphics.lineStyle(4.0, 0xFF0000, rect.strokeAlpha);
			
			var x = rect.x - (rect.width / 2);
			var y = rect.y - (rect.height / 2);
			var w = rect.width;
			var h = rect.height;
			
			graphics.save();
			graphics.translate(th_.x + x, th_.y + y);
			graphics.rotate(rect.rotation);
			
			graphics.fillRect(-(rect.width * rect.scale) / 2, -(rect.height * rect.scale) / 2, w * rect.scale, h * rect.scale);
			
			
			
			graphics.restore();
			//graphics.strokeRect(x, y, w, h);

		}
	}
	
}

function Square(){
	
	this.type = 0;
	this.idx = [0, 0];
	this.x = 0;
	this.y = 0;
	this.width = 5;
	this.height = 5;
	this.scale = 0;
	this.rotation = 0;
	this.fillAlpha = 1;
	this.strokeAlpha = 1;
	this.active = false;
	this.tweens = [];
}